@@ -133,8 +133,24 @@ int psf_write_to_file(FILE *file, struct font_s *font)
   res = fwrite(font->file_hdr, 1, font->header_size, file);
   if(res != font->header_size) return 1;
   /* 2- write glyph data */
-  res = fwrite(font->data, 1, font->data_size, file);
-  if(res != font->data_size) return 1;
+  if(font->width <= 8)
+  {
+    res = fwrite(font->data, 1, font->data_size, file);
+    if(res != font->data_size) return 1;
+  }
+  else
+  {
+    /* swap glyph data if width is more than 1 byte */
+    if(font->width <= 16)
+    {
+      int i;
+      for(i = 0; i < font->data_size; i += 2)
+      {
+	res = fputc(font->data[i+1], file);
+	res = fputc(font->data[i  ], file);
+      }
+    }
+  }
   /* 3- write unicode table */
   if(font->has_unicode_table)
   {
@@ -347,6 +363,21 @@ struct font_s *psf_load_font(unsigned char *file_data, long file_size)
 	else
 		memcpy((void *)font->data, (void *)(file_data+hdr->headersize), font->data_size);
 	
+	/* swap glyph data if width is more than 1 byte */
+	if(font->width > 8)
+	{
+	  if(font->width <= 16)
+	  {
+	    int i;
+	    for(i = 0; i < font->data_size; i += 2)
+	    {
+	      unsigned char c = font->data[i];
+	      font->data[i] = font->data[i+1];
+	      font->data[i+1] = c;
+	    }
+	  }
+	}
+	
 	if(font->has_unicode_table)
 	{
 		unsigned int unicode_size = file_size-font->data_size;
@@ -377,15 +408,19 @@ struct font_s *psf_load_font(unsigned char *file_data, long file_size)
 
 undefined_error:
 	status_error("Error creating new font");
+	//msgBox("Error creating new font", OK, ERROR);
 	goto end;
 file_corrupt:
 	status_error("Font file is corrput!");
+	//msgBox("Font file is corrput!", OK, ERROR);
 	goto end;
 file_read_error:
 	status_error("Error reading font file");
+	//msgBox("Error reading font file", OK, ERROR);
 	goto end;
 memory_error:
 	status_error("Not enough memory to load font file");
+	//msgBox("Insufficient memory", OK, ERROR);
 end:
 	kill_font(font);
 	return (struct font_s *)NULL;
