@@ -321,15 +321,18 @@ void refresh_left_window(struct font_s *font)
     if(font->width <= 8)
     {
       line = (int)data[0]; data++;
+      if(font->width < 8) index <<= (8-font->width);
     }
     else if(font->width <= 16)
     {
       line = (int)(data[0] | (int)(data[1] << 8));
+      if(font->width < 16) index <<= (16-font->width);
       data += 2;
     }
     else if(font->width <= 32)
     {
       line = (int)(data[0] | ((int)(data[1]) << 8) | ((int)(data[2]) << 16) | ((int)(data[3] << 24)));
+      if(font->width < 32) index <<= (32-font->width);
       data += 4;
     }
     /* 
@@ -388,7 +391,7 @@ void create_status_msg(char *smsg, char *msg, struct font_s *font)
 {
   char *help_msg = "| ^H help | ^Q quit";
   char m[(MAX_UNICODE_TABLE_ENTRIES*7)+10];
-  char t[8];
+  char t[12];
   smsg[0] = '\0';
   m[0] = '\0';
   
@@ -477,7 +480,7 @@ void _refresh_view(char *msg, int status, struct font_s *font)
     return;
   }
   
-  char smsg[SCREEN_W+1];
+  char smsg[SCREEN_W+2];
   create_status_msg(smsg, msg, font);
   status_msg(smsg);
   fflush(stdout);
@@ -505,6 +508,8 @@ void calc_max_zoom(struct font_s *font)
 {
   int zoom_w = left_window.width/font->width;
   int zoom_h = left_window.height/font->height;
+  if(zoom_h == 0) zoom_h = 1;
+  if(zoom_w == 0) zoom_w = 1;
   if(zoom_h < zoom_w) font->max_zoom = zoom_h;
   else font->max_zoom = zoom_w;
   font->current_zoom = 1;
